@@ -1,18 +1,10 @@
 /*
- * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007 Jimmy Gilles <jimmygilles@gmail.com>
- * Copyright (C) 2008,2009,2010,2012,2014,2016,2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
- * Copyright (C) 2011 Philip G. Lee <rocketman768@gmail.com>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2002 Jean-Baptiste Mardelle <bj@altern.org>
+    SPDX-FileCopyrightText: 2007 Jimmy Gilles <jimmygilles@gmail.com>
+    SPDX-FileCopyrightText: 2008, 2009, 2010, 2012, 2014, 2016, 2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2011 Philip G. Lee <rocketman768@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KGPGKEYINFODIALOG_H
 #define KGPGKEYINFODIALOG_H
@@ -78,7 +70,7 @@ private:
     void cancelButtonClicked();
 
 private Q_SLOTS:
-    void slotOpenUrl(const QString &url) const;
+    void slotOpenUrl();
 
     void slotChangeDate();
 
