@@ -1,21 +1,8 @@
-/* Copyright 2014  Rolf Eike Beer <kde@opensource.sf-tec.de>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+/*
+    SPDX-FileCopyrightText: 2014 Rolf Eike Beer <kde@opensource.sf-tec.de>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "gpgservermodel.h"
 
@@ -44,9 +31,9 @@ GpgServerModel::setDefault(const int row)
 	const int oldRow = m_defaultRow;
 	m_defaultRow = row;
 	if (oldRow >= 0)
-		emit dataChanged(index(oldRow, 0), index(oldRow, 0));
+		Q_EMIT dataChanged(index(oldRow, 0), index(oldRow, 0));
 	if (row >= 0)
-		emit dataChanged(index(row, 0), index(row, 0));
+		Q_EMIT dataChanged(index(row, 0), index(row, 0));
 }
 
 void
